fnss.netconfig.capacities.set_capacities_edge_communicability — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »

# fnss.netconfig.capacities.set_capacities_edge_communicability

`set_capacities_edge_communicability`(topology, capacities, capacity_unit='Mbps')

  Set link capacities proportionally to edge communicability centrality of the link.

  Parameters : | topology : Topology The topology to which link capacities will be set capacities : list A list of all possible capacity values capacity_unit : str, optional The unit in which capacity value is expressed (e.g. Mbps, Gbps etc..)

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »